![ABSES_banner](https://songshgeo-picgo-1302043007.cos.ap-beijing.myqcloud.com/uPic/CleanShot%202023-10-19%20at%2019.08.12@2x.png)

<div style="text-align: center;">
    <!-- License Badge -->
    <a href="http://www.apache.org/licenses/">
        <img src="https://img.shields.io/github/license/absespy/ABSESpy" alt="license">
    </a>
    <!-- Downloads Badge -->
    <img src="https://img.shields.io/github/downloads/absespy/ABSESpy/total" alt="downloads">
    <!-- Code Size Badge -->
    <img src="https://img.shields.io/github/languages/code-size/absespy/ABSESpy" alt="codesize">
    <!-- Tag Badge -->
    <img src="https://img.shields.io/github/v/tag/absespy/ABSESpy" alt="tag">
    <br>
    <!-- Website Badge -->
    <a href="https://cv.songshgeo.com/">
        <img src="https://img.shields.io/badge/Website-SongshGeo-brightgreen.svg" alt="github">
    </a>
    <!-- Stars Badge -->
    <img src="https://img.shields.io/github/stars/absespy/ABSESpy?style=social" alt="stars">
    <!-- Twitter Badge -->
    <a href="https://twitter.com/shuangsong11">
        <img src="https://img.shields.io/twitter/follow/shuangsong11?style=social" alt="twitter">
    </a>
</div>

<!-- Language: [English Readme](#) | [简体中文](README_ch) -->

An Agent-Based computational framework makes modeling artificial **[Social-ecological systems](https://absespy.github.io/ABSESpy/docs/about/)** easier.

## Why `ABSESpy`?

Agent-based model (ABM) is essential for social-ecological systems (SES) research. `ABSESpy` is designed for modeling **couples humans and nature systems** by:

- [Architectural Elegance for Modular Socio-Ecological Systems Modeling](https://absespy.github.io/ABSESpy/features/architectural_elegance.md).
- [Unveiling Human Decision Dynamics in SES Modeling by an advanced human behavior simulating framework](https://absespy.github.io/ABSESpy/features/MoHuB.md).
- [Mastering Time in SES Modeling with Real-world Precision and Dynamic Updates](https://absespy.github.io/ABSESpy/features/time_control.md).
<!-- - Automatically portray interactions between social actors and natural cells with `Networkx` -->

## Basic Usage & Documents

Install with pip or your favorite PyPI package manager.

```shell
pip install abses
```

Access the [Documentation here](https://absespy.github.io/ABSESpy/).

<img src="https://songshgeo-picgo-1302043007.cos.ap-beijing.myqcloud.com/uPic/DQg0xJ.jpg" alt="Drawing" style="width: 600px;"/>

## Get in touch

- **For enthusiastic developers and contributors**, all contributions, bug reports, bug fixes, documentation improvements, enhancements, and ideas are welcome.
- **SES researchers** are welcome to use this package in social-ecological system (SES) studies. It would be appreciated if you contribute a published model to our gallery.

If you need any help when using `ABSESpy`, don't hesitate to get in touch with us through:

- Ask usage questions ("How to do?") on [_GitHub_ Discussions](https://github.com/absespy/ABSESpy/discussions).
- Report bugs, suggest features, or view the source code [on _GitHub_ Issues](https://github.com/absespy/ABSESpy/issues).
- Use the [mailing list](https://groups.google.com/g/absespy) for less well-defined questions or ideas or to announce other projects of interest to `ABSESpy` users.

## License

Copyright 2023, `ABSESpy` [Shuang Song](https://cv.songshgeo.com/)

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

[https://www.apache.org/licenses/LICENSE-2.0](https://www.apache.org/licenses/LICENSE-2.0)

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

`ABSESpy` bundles portions of `Mesa`, `mesa-geo`, `pandas`, `NumPy`, and `Xarray`; the full text of these licenses are included in the licenses directory.

## Thanks to all contributors

<a href="https://github.com/ABSESpy/ABSESpy/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=ABSESpy/ABSESpy" />
</a>
